/// <reference types="draft-js" />
/// <reference types="react" />
import * as React from 'react';
import React__default from 'react';

interface AieStyleMap {
    [styleName: string]: {
        css: React__default.CSSProperties;
        aieExclude: string[];
    };
}
/** Interface for the AsupInternalEditor component */
interface AsupInternalEditorProps {
    value: string;
    setValue?: (ret: string) => void;
    style?: React__default.CSSProperties;
    styleMap?: AieStyleMap;
    textAlignment?: Draft.DraftComponent.Base.DraftTextAlignment;
    showStyleButtons?: boolean;
    editable?: boolean;
}
declare const AsupInternalEditor: ({ value, setValue, style, styleMap, textAlignment, showStyleButtons, editable, }: AsupInternalEditorProps) => JSX.Element;

interface AifBlockLine {
    aifid?: string;
    left?: string | false;
    centre?: string | false;
    right?: string | false;
    addBelow?: boolean;
    canEdit?: boolean;
    canRemove?: boolean;
    canMove?: boolean;
}
declare const enum AifLineType {
    leftOnly = "Left only",
    centreOnly = "Centre only",
    leftAndRight = "Left and Right",
    leftCentreAndRight = "Left, Centre and Right"
}

interface AsupInternalBlockProps {
    lines: AifBlockLine[];
    setLines?: (ret: AifBlockLine[]) => void;
    minLines?: number;
    maxLines?: number;
    styleMap?: AieStyleMap;
    defaultType?: AifLineType;
}
declare const AsupInternalBlock: ({ lines, setLines, minLines, maxLines, styleMap, defaultType, }: AsupInternalBlockProps) => JSX.Element;

interface AioDropSelectProps {
    value?: string;
    availableValues?: Array<string>;
    setValue?: (value: string) => void;
}
/**
 * Wrapper to preprend Icon button with chosen text
 */
declare const AioDropSelect: ({ value, setValue, availableValues }: AioDropSelectProps) => JSX.Element;

interface AioExpanderProps {
    inputObject?: {
        [key: string]: any;
    };
    label?: string;
    showBorders?: boolean;
    updateObject?: (value: any) => void;
    canAddItems?: boolean;
    canMoveItems?: boolean;
    canRemoveItems?: boolean;
}
declare const AioExpander: (props: AioExpanderProps) => JSX.Element;

interface AioIconButtonProps {
    onClick: (ret: string) => void;
    iconName?: string;
    tipText?: string;
    menuItems?: string[];
    leftMenuOffset?: string;
    style?: React__default.CSSProperties;
}
declare const AioIconButton: ({ onClick, iconName, tipText, menuItems, leftMenuOffset, style, }: AioIconButtonProps) => JSX.Element;

/** Individual options */
interface AioOption {
    optionName?: AioNewItem;
    type: AioOptionType;
    value: any;
    label?: string;
    availableValues?: string[];
    readOnly?: boolean;
}
interface AioOptionGroup extends Array<AioOption> {
}
/** Individual text replacements */
interface AioReplacementText {
    text: string;
    spaceAfter: boolean;
}
/** Single replacement value, allowing for sublists */
interface AioReplacementValue {
    newText: string;
    subList?: AioReplacementValue[];
}
/** Text replacements, and their replacement matrix */
interface AioReplacement {
    airid?: string;
    replacementTexts: AioReplacementText[];
    replacementValues: AioReplacementValue[];
    givenName?: string;
    externalName?: string;
}
declare enum AioOptionType {
    string = "string",
    number = "number",
    array = "array",
    object = "object",
    boolean = "boolean",
    select = "select",
    replacements = "replacements"
}
declare enum AioNewItem {
    newKey = "newKey",
    newType = "newType"
}

interface AioReplacmentTableProps {
    airid?: string;
    replacementTexts: AioReplacementText[];
    replacementValues: AioReplacementValue[];
    givenName?: string;
    externalName?: string;
    setReplacement: (ret: AioReplacement) => void;
    externalLists?: AioReplacement[];
    dontAskSpace?: boolean;
    dontShowText?: boolean;
}
/**
 * Render an individuial AioReplacement
 * @param props value/setValue pair
 */
declare const AioReplacementTable: ({ airid, replacementTexts, replacementValues, givenName, externalName, setReplacement, externalLists, dontAskSpace, dontShowText }: AioReplacmentTableProps) => JSX.Element;

interface AioStringProps {
    label?: string;
    value?: string;
    setValue?: (value: string) => void;
}
declare const AioString: (props: AioStringProps) => JSX.Element;

interface AitCellData {
    aitid?: string;
    text: string;
    comments?: string;
    colSpan?: number;
    rowSpan?: number;
    colWidth?: number;
    textIndents?: number;
    replacedText?: string;
    repeatColSpan?: number;
    repeatRowSpan?: number;
}
interface AitRowData {
    aitid?: string;
    cells: AitCellData[];
    spaceAfter?: number | false;
}
interface AitRowGroupData {
    aitid?: string;
    name?: string;
    rows: Array<AitRowData>;
    comments?: string;
    spaceAfter?: boolean;
    replacements?: AioReplacement[];
}
interface AitTableData {
    headerData: AitRowGroupData;
    bodyData: AitRowGroupData[];
    comments?: string;
    rowHeaderColumns: number;
    noRepeatProcessing: boolean;
}

interface AsupInternalTableProps {
    tableData: AitTableData;
    setTableData: (ret: AitTableData) => void;
    externalLists?: AioReplacement[];
    style?: React__default.CSSProperties;
    showCellBorders?: boolean;
    groupTemplates?: AitRowGroupData[] | false;
    commentStyles?: AieStyleMap;
    cellStyles?: AieStyleMap;
}
/**
 * Table view for clinical table data
 * @param props
 * @returns
 */
declare const AsupInternalTable: ({ tableData, setTableData, externalLists, style, showCellBorders, groupTemplates, commentStyles, cellStyles, }: AsupInternalTableProps) => JSX.Element;

interface AsupInternalWindowProps {
    Title: string;
    Visible: boolean;
    onClose: () => void;
    style?: React.CSSProperties;
    children?: React.ReactChild | React.ReactChild[];
}
declare const AsupInternalWindow: (props: AsupInternalWindowProps) => JSX.Element;

export { AieStyleMap, AifBlockLine, AifLineType, AioDropSelect, AioExpander, AioIconButton, AioOption, AioOptionGroup, AioReplacement, AioReplacementTable, AioReplacementText, AioReplacementValue, AioString, AitCellData, AitRowData, AitRowGroupData, AitTableData, AsupInternalBlock, AsupInternalEditor, AsupInternalTable, AsupInternalWindow };
